# reprdle

### Play wordle in the repl with the power of __repr__!

Just install with pip:

```bash
pip install reprdle
```

The open a python repl and play!

![example](example.png)

> Note: This is probably some of the worst code I have ever written. I tried to abuse the Python language as much as possible, and reprdle is the result.
